aboutsummaryrefslogtreecommitdiffstats
path: root/wsutil/filesystem.h
diff options
context:
space:
mode:
authorStig Bjørlykke <stig@bjorlykke.org>2019-07-30 10:12:30 +0200
committerStig Bjørlykke <stig@bjorlykke.org>2019-07-30 10:11:10 +0000
commit5d0a2ccbb7119c667b078e8346e8e900f169e7df (patch)
tree09e7e1288afe8a07bae4ed74f6435508eb350b90 /wsutil/filesystem.h
parentd614865c8ca5db9477d7d68cb241e94da91f6c17 (diff)
Qt: Change from User/System to Personal/Global profile types
Change the Profile types from User/System to Personal/Global in UI to match the terminology used in About Wireshark -> Folders. This reverts commit 40af4aa93e469d37bd8e712228ecccb07407c3c6. This reverts commit f0cde7ca34a4975370e1b9ded2fee7df266343f6. This reverts commit c37cabe900b9b11e12c8626ca46adc080e465fdb. Change-Id: I9012db6385707754e26a2dadb57f6003f8112f9b Reviewed-on: https://code.wireshark.org/review/34134 Petri-Dish: Stig Bjørlykke <stig@bjorlykke.org> Tested-by: Petri Dish Buildbot Reviewed-by: Roland Knall <rknall@gmail.com> Reviewed-by: Stig Bjørlykke <stig@bjorlykke.org>
Diffstat (limited to 'wsutil/filesystem.h')
-rw-r--r--wsutil/filesystem.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/wsutil/filesystem.h b/wsutil/filesystem.h
index 712b74444a..e00794899e 100644
--- a/wsutil/filesystem.h
+++ b/wsutil/filesystem.h
@@ -72,13 +72,13 @@ WS_DLL_PUBLIC const char *get_extcap_dir(void);
WS_DLL_PUBLIC gboolean running_in_build_directory(void);
/*
* Get the directory in which system configuration files are
* stored.
*/
WS_DLL_PUBLIC const char *get_datafile_dir(void);
/*
* Construct the path name of a system configuration file, given the
* file name.
*
* The returned file name was g_malloc()'d so it must be g_free()d when the
@@ -90,7 +90,7 @@ WS_DLL_PUBLIC char *get_datafile_path(const char *filename);
* Get the directory in which files that, at least on UNIX, are
* system files (such as "/etc/ethers") are stored; on Windows,
* there's no "/etc" directory, so we get them from the Wireshark
* system configuration and data file directory.
*/
WS_DLL_PUBLIC const char *get_systemfile_dir(void);
@@ -112,9 +112,9 @@ WS_DLL_PUBLIC const char *get_profile_name(void);
WS_DLL_PUBLIC gboolean is_default_profile(void);
/*
* Check if we have system profiles.
*/
-WS_DLL_PUBLIC gboolean has_system_profiles(void);
+WS_DLL_PUBLIC gboolean has_global_profiles(void);
/*
* Get the directory used to store configuration profile directories.
@@ -126,7 +126,7 @@ WS_DLL_PUBLIC char *get_profiles_dir(void);
* Get the directory used to store configuration files for a given profile.
* Caller must free the returned string.
*/
-WS_DLL_PUBLIC char *get_profile_dir(const char *profilename, gboolean is_system);
+WS_DLL_PUBLIC char *get_profile_dir(const char *profilename, gboolean is_global);
/*
* Create the directory used to store configuration profile directories.
@@ -134,10 +134,10 @@ WS_DLL_PUBLIC char *get_profile_dir(const char *profilename, gboolean is_system)
WS_DLL_PUBLIC int create_profiles_dir(char **pf_dir_path_return);
/*
* Get the directory used to store system configuration profile directories.
* Caller must free the returned string
*/
-WS_DLL_PUBLIC char *get_system_profiles_dir(void);
+WS_DLL_PUBLIC char *get_global_profiles_dir(void);
/*
@@ -149,7 +149,7 @@ WS_DLL_PUBLIC void profile_store_persconffiles(gboolean store);
/*
* Check if given configuration profile exists.
*/
-WS_DLL_PUBLIC gboolean profile_exists(const gchar *profilename, gboolean is_system);
+WS_DLL_PUBLIC gboolean profile_exists(const gchar *profilename, gboolean global);
/*
* Create a directory for the given configuration profile.
@@ -182,7 +182,7 @@ WS_DLL_PUBLIC int rename_persconffile_profile(const char *fromname, const char *
* Copy files in one profile to the other.
*/
WS_DLL_PUBLIC int copy_persconffile_profile(const char *toname, const char *fromname,
- gboolean from_system,
+ gboolean from_global,
char **pf_filename_return,
char **pf_to_dir_path_return,
char **pf_from_dir_path_return);
@@ -72,13 +72,13 @@ WS_DLL_PUBLIC const char *get_extcap_dir(void);
WS_DLL_PUBLIC gboolean running_in_build_directory(void);
/*
- * Get the directory in which system configuration files are
+ * Get the directory in which global configuration files are
* stored.
*/
@@ -72,13 +72,13 @@ WS_DLL_PUBLIC const char *get_extcap_dir(void);
WS_DLL_PUBLIC const char *get_datafile_dir(void);
/*
- * Construct the path name of a system configuration file, given the
+ * Construct the path name of a global configuration file, given the
* file name.
*
@@ -90,7 +90,7 @@ WS_DLL_PUBLIC char *get_datafile_path(const char *filename);
* system files (such as "/etc/ethers") are stored; on Windows,
* there's no "/etc" directory, so we get them from the Wireshark
- * system configuration and data file directory.
+ * global configuration and data file directory.
*/
WS_DLL_PUBLIC const char *get_systemfile_dir(void);
@@ -112,9 +112,9 @@ WS_DLL_PUBLIC const char *get_profile_name(void);
WS_DLL_PUBLIC gboolean is_default_profile(void);
/*
- * Check if we have system profiles.
+ * Check if we have global profiles.
*/
@@ -134,10 +134,10 @@ WS_DLL_PUBLIC char *get_profile_dir(const char *profilename, gboolean is_system)
WS_DLL_PUBLIC int create_profiles_dir(char **pf_dir_path_return);
/*
- * Get the directory used to store system configuration profile directories.
+ * Get the directory used to store global configuration profile directories.
* Caller must free the returned string
*/